Subscribers
===========

Subscriber
----------
.. autoclass:: broqer.Subscriber

Sink
----
.. autoclass:: broqer.op.Sink

SinkAsync
---------
.. autoclass:: broqer.op.SinkAsync

OnEmitFuture
------------
.. autoclass:: broqer.op.OnEmitFuture

Trace
-----
.. autoclass:: broqer.op.Trace

TopicMapper
-----------
.. autoclass:: broqer.hub.utils.TopicMapper